@@ -5,13 +5,16 @@
     (c) 2010-2011 by Hans-Peter Deifel
     (c) 2010-2011 by Thomas Adam
     (c) 2011 by Albert Kim
+    (c) 2013 Daniel Carl
     see LICENSE file
 */
 
 /* Vimprobable version number */
-#define VERSION "1.2.1"
+#define VERSION "1.4.0"
 #define INTERNAL_VERSION "Vimprobable2/"VERSION
 
+extern Client client;
+
 /* general settings */
 char startpage[MAX_SETTING_SIZE]      = "http://www.vimprobable.org/";
 char useragent[MAX_SETTING_SIZE]      = "Vimprobable2/" VERSION;
@@ -22,6 +25,9 @@ static const gboolean enablePagecache   = FALSE; /* TRUE turns on the page cache
 static gboolean escape_input_on_load    = TRUE; /* TRUE will disable automatic focusing of input fields via Javascript*/
 char temp_dir[MAX_SETTING_SIZE]         = "/tmp"; /* location of temporary files, default will be overridden if TEMPDIR is set */
 
+char downloads_path[MAX_SETTING_SIZE]   = "";
+char statusfont[MAX_SETTING_SIZE]       = "monospace bold 8";   /* font for status bar */
+
 /* appearance */
 char statusbgcolor[MAX_SETTING_SIZE]    = "#000000";            /* background color for status bar */
 char statuscolor[MAX_SETTING_SIZE]      = "#ffffff";            /* color for status bar */
@@ -30,12 +36,12 @@ char sslinvalidbgcolor[MAX_SETTING_SIZE]= "#ff0000";            /* background co
 char sslcolor[MAX_SETTING_SIZE]         = "#000000";            /* color for status bar with SSL url */
 
                                         /*  normal,                 warning,                error       */
-static const char *urlboxfont[]         = { "monospace normal 8",   "monospace normal 8",   "monospace bold 8"};
+char urlboxfont[][MAX_SETTING_SIZE]     = { "monospace normal 8",   "monospace normal 8",   "monospace bold 8"};
 static const char *urlboxcolor[]        = { NULL,                   "#ff0000",              "#ffffff" };
 static const char *urlboxbgcolor[]      = { NULL,                   NULL,                   "#ff0000" };
 
                                         /*  normal,                 error               */
-static const char *completionfont[]     = { "monospace normal 8",   "monospace bold 8" };
+char completionfont[2][MAX_SETTING_SIZE] = { "monospace normal 8",   "monospace bold 8" };
                                                                                         /* topborder color */
 static const char *completioncolor[]    = { "#000000",              "#ff00ff",              "#000000" };
                                                                                         /* current row background */
@@ -44,7 +50,6 @@ static const char *completionbgcolor[]  = { "#ffffff",              "#ffffff",
 #define             COMPLETION_TAG_OPEN     "<b>"
 #define             COMPLETION_TAG_CLOSE    "</b>"
 
-static const char statusfont[]          = "monospace bold 8";   /* font for status bar */
 #define             ENABLE_HISTORY_INDICATOR
 #define             ENABLE_INCREMENTAL_SEARCH
 #define             ENABLE_GTK_PROGRESS_BAR
@@ -72,21 +77,20 @@ static URIHandler uri_handlers[] = {
 
 /* cookies */
 #define             ENABLE_COOKIE_SUPPORT
-#define             COOKIES_STORAGE_FILENAME    "%s/vimprobable/cookies", config_base
+#define             COOKIES_STORAGE_FILENAME    "%s/vimprobable/cookies", client.config.config_base
 #define             COOKIES_STORAGE_READONLY    FALSE   /* if TRUE new cookies will be lost if you quit */
+SoupCookieJarAcceptPolicy CookiePolicy = SOUP_COOKIE_JAR_ACCEPT_ALWAYS; /* by default, accept all cookies */
 
-/* downloads directory */
-#define             DOWNLOADS_PATH              "%s", getenv("HOME")
 
 /* font size */
 #define             DEFAULT_FONT_SIZE           12
 
 /* user styles */
-#define             USER_STYLESHEET             "%s/vimprobable/style.css", config_base
+#define             USER_STYLESHEET             "%s/vimprobable/style.css", client.config.config_base
 
 /* user javascript */
 #define             ENABLE_USER_SCRIPTFILE
-#define             USER_SCRIPTFILE             "%s/vimprobable/scripts.js", config_base
+#define             USER_SCRIPTFILE             "%s/vimprobable/scripts.js", client.config.config_base
 
 /* ssl */
 static gboolean strict_ssl              = TRUE; /* FALSE will accept any SSL certificate at face value */
@@ -162,6 +166,10 @@ Command commands[COMMANDSIZE] = {
     { "scrollright",                                    scroll,           {ScrollMove     | DirectionRight    | UnitLine} },
     { "scrollup",                                       scroll,           {ScrollMove     | DirectionTop      | UnitLine} },
     { "scrolldown",                                     scroll,           {ScrollMove     | DirectionBottom   | UnitLine} },
+    { "zi",                                             zoom,             {ZoomIn         | ZoomText} },
+    { "zo",                                             zoom,             {ZoomOut        | ZoomText} },
+    { "pgzi",                                           zoom,             {ZoomIn         | ZoomFullContent} },
+    { "pgzo",                                           zoom,             {ZoomOut        | ZoomFullContent} },
 };
 
 /* mouse bindings
@@ -169,7 +177,7 @@ Command commands[COMMANDSIZE] = {
 */
 static Mouse mouse[] = {
     /* modmask,             modkey,         button,            function,        argument */
-    { 0,                    0,              MOUSE_BUTTON_2,    paste,           {TargetCurrent  | ClipboardPrimary  | ClipboardGTK, rememberedURI} },
+    { 0,                    0,              MOUSE_BUTTON_2,    paste,           {TargetCurrent  | ClipboardPrimary  | ClipboardGTK, client.state.rememberedURI} },
     { GDK_CONTROL_MASK,     0,              MOUSE_BUTTON_2,    paste,           {TargetNew  | ClipboardPrimary  | ClipboardGTK} },
     { GDK_CONTROL_MASK,     0,              MOUSE_BUTTON_1,    open_remembered, {TargetNew} },
 };
@@ -207,6 +215,14 @@ static Setting browsersettings[] = {
     { "sslcolor",        sslcolor,           "",                            FALSE,          FALSE,           TRUE,           TRUE   },
     { "acceptlanguage",  acceptlanguage,     "",                            FALSE,          FALSE,           FALSE,          FALSE  },
     { "defaultsearch",   defaultsearch,      "",                            FALSE,          FALSE,           FALSE,          FALSE  },
+    { "cookies",         NULL,               "",                            FALSE,          FALSE,           FALSE,          FALSE  },
+    { "downloadspath",   downloads_path,     "",                            FALSE,          FALSE,           FALSE,          FALSE  },
+    { "statusfont",      statusfont,         "",                            FALSE,          FALSE,           FALSE,          FALSE  },
+    { "urlboxfontnormal",urlboxfont[0],      "",                            FALSE,          FALSE,           FALSE,          FALSE  },
+    { "urlboxfontwarning",urlboxfont[1],      "",                           FALSE,          FALSE,           FALSE,          FALSE  },
+    { "urlboxfonterror", urlboxfont[2],      "",                            FALSE,          FALSE,           FALSE,          FALSE  },
+    { "completionfontnormal", completionfont[0],      "",                   FALSE,          FALSE,           FALSE,          FALSE  },
+    { "completionfonterror",  completionfont[1],      "",                   FALSE,          FALSE,           FALSE,          FALSE  },
     { "qmark",           NULL,               "",                            FALSE,          FALSE,           FALSE,          FALSE  },
     { "proxy",           NULL,               "",                            FALSE,          TRUE,            FALSE,          FALSE  },
     { "windowsize",      NULL,               "",                            FALSE,          FALSE,           FALSE,          FALSE  },
