@@ -4,6 +4,7 @@
     (c) 2009-2010 by Matto Fransen
     (c) 2010-2011 by Hans-Peter Deifel
     (c) 2010-2011 by Thomas Adam
+    (c) 2013 Daniel Carl
     see LICENSE file
 */
 
@@ -12,20 +13,17 @@
 #include "main.h"
 #include "utilities.h"
 
-extern GList *commandhistory, *colon_aliases;
-extern int commandpointer;
+extern Client client;
 extern Command commands[COMMANDSIZE];
-extern KeyList *keylistroot;
 extern Key keys[];
-extern char *error_msg;
 extern gboolean complete_case_sensitive;
-extern char *config_base;
 static GList *dynamic_searchengines = NULL, *dynamic_uri_handlers = NULL;
 
 void add_modkeys(char key);
 
 void save_command_history(char *line)
 {
+    State *s = &client.state;
 	char *c = line;
 
 	while (isspace(*c) && *c)
@@ -33,11 +31,11 @@ void save_command_history(char *line)
 	if (!strlen(c))
 		return;
 
-    if (COMMANDHISTSIZE <= g_list_length(commandhistory)) {
+    if (COMMANDHISTSIZE <= g_list_length(s->commandhistory)) {
         /* if list is too long - remove items from beginning */
-        commandhistory = g_list_delete_link(commandhistory, g_list_first(commandhistory));
+        s->commandhistory = g_list_delete_link(s->commandhistory, g_list_first(s->commandhistory));
     }
-    commandhistory = g_list_append(commandhistory, g_strdup(c));
+    s->commandhistory = g_list_append(s->commandhistory, g_strdup(c));
 }
 
 gboolean
@@ -110,8 +108,10 @@ make_keyslist(void)
         }
         current->Element = keys[i];
         current->next = NULL;
-        if (keylistroot == NULL) keylistroot = current;
-        if (ptr != NULL) ptr->next = current;
+        if (client.config.keylistroot == NULL)
+            client.config.keylistroot = current;
+        if (ptr != NULL)
+            ptr->next = current;
         ptr = current;
         i++;
     }
@@ -206,7 +206,7 @@ changemapping(Key *search_key, int maprecord, char *cmd) {
         return FALSE;
     }
 
-    current = keylistroot;
+    current = client.config.keylistroot;
 
     if (current)
         while (current->next != NULL) {
@@ -249,9 +249,11 @@ changemapping(Key *search_key, int maprecord, char *cmd) {
 
     newkey->next           = NULL;
 
-    if (keylistroot == NULL) keylistroot = newkey;
+    if (client.config.keylistroot == NULL)
+        client.config.keylistroot = newkey;
 
-    if (current != NULL) current->next = newkey;
+    if (current != NULL)
+        current->next = newkey;
 
     return TRUE;
 }
@@ -259,15 +261,14 @@ changemapping(Key *search_key, int maprecord, char *cmd) {
 void add_modkeys(char key)
 {
     unsigned int k, len;
-    extern char *modkeys;
-    len = strlen( modkeys );
+    len = strlen(client.config.modkeys );
     while (k < len ) { 
-        if ( modkeys[k] == key ) return;
+        if (client.config.modkeys[k] == key ) return;
         k++;
     }
-    modkeys = realloc(modkeys, len + 2);
-    modkeys[len] = key;
-    modkeys[len+1] = '\0';
+    client.config.modkeys = realloc(client.config.modkeys, len + 2);
+    client.config.modkeys[len] = key;
+    client.config.modkeys[len+1] = '\0';
 }
 
 gboolean
@@ -315,9 +316,11 @@ process_colon(char *alias, char *cmd) {
         fprintf(stderr, "Memory exhausted while saving new command.\n");
         exit(EXIT_FAILURE);
     }
-    a->alias = ++alias;
+    a->alias = malloc(strlen(alias)*sizeof(char));
+    memset(a->alias, 0, strlen(alias));
+    strncpy(a->alias, (alias + 1), strlen(alias) - 1);
     a->target = cmd;
-    colon_aliases = g_list_prepend(colon_aliases, a);
+    client.config.colon_aliases = g_list_prepend(client.config.colon_aliases, a);
     return TRUE;
 }
 
@@ -498,8 +501,8 @@ set_error(const char *error) {
     /* it should never happen that set_error is called more than once, 
      * but to avoid any potential memory leaks, we ignore any subsequent 
      * error if the current one has not been shown */
-    if (error_msg == NULL) {
-        error_msg = g_strdup_printf("%s", error);
+    if (client.state.error_msg == NULL) {
+        client.state.error_msg = g_strdup_printf("%s", error);
     }
 }
 
@@ -564,7 +567,7 @@ complete_list(const char *searchfor, const int mode, Listelement *elementlist)
         while (candidatepointer != NULL) {
             strncpy(s, candidatepointer->element, sizeof(s));
             if (!complete_case_sensitive) {
-                g_strdown(s);
+                g_utf8_strdown(s, 255);
             }
             if (!strlen(searchfor) || strstr(s, searchfor) != NULL) {
                 /* only use string up to the first space */
@@ -699,7 +702,7 @@ static gboolean sanity_check_search_url(const char *string)
         }
     }
 
-    return !was_percent_char && percent_s_count == 1;
+    return percent_s_count == 0 || percent_s_count == 1;
 }
 
 void make_searchengines_list(Searchengine *searchengines, int length)
@@ -755,8 +758,12 @@ read_rcfile(const char *config)
 			continue;
 		t = strlen(s);
 		s[t - 1] = '\0';
-		if (strncmp(s, "searchengine", 12) == 0) {
-			buffer = (s + 12);
+		if (strncmp(s, "shortcut", 8) == 0 || strncmp(s, "searchengine", 12) == 0) {
+			if (strncmp(s, "shortcut", 8) == 0) {
+				buffer = (s + 8);
+			} else {
+				buffer = (s + 12);
+			}
 			while (buffer[0] == ' ')
 				buffer++;
 			/* split line at whitespace */
